@@ -5,8 +5,8 @@ import math
 import os
 import subprocess
 
-from plotmanx import archive, configuration, manager, reporting
-from plotmanx.job import Job
+from . import archive, configuration, manager, reporting
+from .job import Job
 
 
 class TerminalTooSmallError(Exception):
@@ -168,6 +168,7 @@ def curses_main_v2(stdscr):
         #
 
         # Directory prefixes, for abbreviation
+        arch_prefix = ''
         tmp_prefix = os.path.commonpath(cfg.directories.tmp)
         dst_prefix = os.path.commonpath(cfg.directories.dst)
         if archiving_configured:
@@ -452,7 +453,9 @@ def curses_main_v1(stdscr):
 
         # Directory prefixes, for abbreviation
         tmp_prefix = os.path.commonpath(cfg.directories.tmp)
-        dst_prefix = os.path.commonpath(cfg.directories.dst)
+        (is_dst, dst_dir) = configuration.get_dst_directories(cfg.directories)
+        arch_prefix = ''
+        dst_prefix = os.path.commonpath(dst_dir)
         if archiving_configured:
             arch_prefix = cfg.directories.archive.rsyncd_path
 
@@ -465,7 +468,7 @@ def curses_main_v1(stdscr):
         tmp_report_2 = reporting.tmp_dir_report(
             jobs, cfg.directories, cfg.scheduling, n_cols, n_tmpdirs_half, n_tmpdirs, tmp_prefix)
         dst_report = reporting.dst_dir_report(
-            jobs, cfg.directories.dst, n_cols, dst_prefix)
+            jobs, dst_dir, n_cols, dst_prefix)
         if archiving_configured:
             arch_report = reporting.arch_dir_report(archdir_freebytes, n_cols, arch_prefix)
             if not arch_report:
@@ -546,8 +549,7 @@ def curses_main_v1(stdscr):
         header_win.addnstr(' (remote)', linecap)
 
         # Jobs
-        jobs_win.addstr(0, 0, reporting.status_report(jobs, n_cols, jobs_h,
-                                                      tmp_prefix, dst_prefix))
+        jobs_win.addstr(0, 0, reporting.status_report(jobs, n_cols, jobs_h, tmp_prefix, dst_prefix))
         jobs_win.chgat(0, 0, curses.A_REVERSE)
 
         # Dirs
@@ -629,7 +631,7 @@ def run_interactive():
     # Then use code as the encoding for str.encode() calls.
 
     try:
-        curses.wrapper(curses_main_v1)
+        curses.wrapper(curses_main_v2)
     except curses.error as e:
         raise TerminalTooSmallError(
             "Your terminal may be too small, try making it bigger.",
